#!/bin/bash -e

SCRIPTS_DIR=$(cd "$(dirname "$0")" && pwd) || exit
PROJECT_HOME="$SCRIPTS_DIR/.."
BIN_DIR="usr/bin"
DEV_FILES_DIR="$PROJECT_HOME/container/dev"
RESOURCES_DIR="$DEV_FILES_DIR/resources"
APP_DIR="$PROJECT_HOME/app"
APP_NAME=$(cd $APP_DIR && yq -r '.name' pubspec.yaml)
IMAGE_NAME="${APP_NAME}_dev_image"
IMAGE_TAG="latest"
DESC_FILE="$DEV_FILES_DIR/${IMAGE_NAME}.desc"
OUT_SWU="$DEV_FILES_DIR/${IMAGE_NAME}.swu"
TEMPLATE_DIR="$DEV_FILES_DIR/template"
CONF_TEMPLATE_FILE="container.conf.tmpl"
ROOT_CONF_DIR="$DEV_FILES_DIR/root/etc/atmark/containers"
APP_START_TEMPLATE_FILE="app_start.tmpl"

gen_swu() {
	declare -a desc_files=(
		"$DESC_FILE"
	)

	version=1

	if [ -e "$DESC_FILE" ]; then
		version=$(awk -F= '$1 == "swdesc_option version" { print $2 + 1 }' "$DESC_FILE")
		mv -f "$DESC_FILE" "$DESC_FILE".old
	fi
	cat > "$DESC_FILE" <<EODESC
swdesc_option version=${version:-1}

swdesc_files --extra-os container/dev/root
swdesc_command --extra-os "sed -i -e 's/^AllowTcpForwarding no/#&/' /etc/ssh/sshd_config"
swdesc_embed_container "container/dev/${IMAGE_NAME}.tar"
EODESC

	# enable sshd on armadillo
	desc_files+=(
		"$PROJECT_HOME/container/dev/enable_sshd.desc"
	)
	# and also remove known hosts in case of reinstall
	rm -f "$PROJECT_HOME/config/ssh_known_hosts"

	# merge all desc contents together in order to share
	# same version, which would be reset with different files
	cat "${desc_files[@]}" \
		| mkswu -o "$OUT_SWU" - \
		|| exit
}

sed -e "s/{{IMAGE_NAME}}/$IMAGE_NAME/g" -e "s/{{IMAGE_TAG}}/$IMAGE_TAG/g" -e "s/{{APP_NAME}}/$APP_NAME/g" \
	"$TEMPLATE_DIR"/"$CONF_TEMPLATE_FILE" > "$ROOT_CONF_DIR"/"$APP_NAME".conf
sed -e "s/{{APP_NAME}}/$APP_NAME/g" "$TEMPLATE_DIR"/"$APP_START_TEMPLATE_FILE" \
    > "$RESOURCES_DIR/$BIN_DIR/$APP_NAME"
chmod +x "$RESOURCES_DIR/$BIN_DIR/$APP_NAME"

"$SCRIPTS_DIR"/build_container_image.sh dev || exit
gen_swu

echo $"Install $OUT_SWU on Armadillo next"
