if command -v gettext > /dev/null; then
	_gettext() { gettext -- "$@"; }
else
	_gettext() { printf -- "%s" "$@"; }
fi

prompt() {
	local var="$1"
	local prompt_fmt="$2"
	shift 2
	# shellcheck disable=SC2059 # fmt is a build time constant
	printf -- "$(_gettext "$prompt_fmt") " "$@"
	read -r "${var?}"
}

prompt_yesno() {
	local default="$1"
	shift 1
	local yesno

	while true; do
		prompt yesno "$@"
		[ -n "$yesno" ] || yesno="$default"
		case "$yesno" in
		[Yy]|[Yy][Ee][Ss]|[Tt][Rr][Uu][Ee]|1)
			return 0;;
		[Nn]|[Nn][Oo]|[Ff][Aa][Ll][Ss][Ee]|0)
			return 1;;
		esac
	done
}

copy_run() {
	local source dest

	[ "$#" -lt 2 ] && return
	source=$1
	dest=$2
	shift 2

	# copy to dest without removing dest dir (breaks volume)
	tar -C "$source" -cz . \
		| ssh -F config/ssh_config Armadillo '
			d='"${dest@Q}"';
			find "$d" -mindepth 1 -delete && tar -C "$d" -xz'

	# Copy only -- stop here.
	[ "$#" = 0 ] && return
	container="$1"

	ssh -F config/ssh_config Armadillo "podman_start $container \
		&& sleep 2 && podman exec -i $container /var/volumes/${container} -b /var/volumes -f \
		&& podman logs -f $container"
}
